## About the EDICTOR

The EDICTOR is an etymological dictionary editor. Based on simple text files as input and output, but also equipped with a server-based database-backend, you can create word lists for specific language families, add phonetic transcriptions to your data using X-SAMPA input, automatically segment your phonetic data, search for cognates, annotated cognates, align cognate words, and carry out language-internal morphological analyses.

### Thirdparty Libraries used by the EDICTOR

The EDICTOR makes heavily use of many thirdparty libraries and plugins which other people have programmed and published. Here is a list of all currently used thirdparty software applications:

- Bootstrap: General appearance of the application.
- Bootstrap Multiselect: Multiselect buttons in the application.
- FileSaver.js: Cross-browser file saving.
- Javascript-Undo-Manager: Undo-Redo functionalities in the application.
- jQuery: Basic programming backend.
- jQuery UI: Many UI-related programming applications.
- JSURL: Specific format for handling complex URL parameters.
- sigmajs: Visualization of large word family networks.
- Springy.js: Visualization of morpheme networks.
- spin.js: Showing spinner while loading files and data.